pub struct PrivateKey { /* private fields */ }Expand description
A validated secp256k1 private key that zeroizes its bytes on drop.
Created by generate. The key is guaranteed to be a
valid scalar in the range [1, n-1] where n is the secp256k1 curve order.
When this value goes out of scope, the underlying bytes are securely overwritten with zeros to prevent secrets from lingering in memory.
Implementations
Sourceimpl PrivateKey
impl PrivateKey
Sourcepub fn to_secret_key(&self) -> SecretKey
pub fn to_secret_key(&self) -> SecretKey
Converts the private key into a secp256k1::SecretKey for use with
the secp256k1 crate directly.